==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QTemporaryDir_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qtemporarydir.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTemporaryDir(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTemporaryDir")
    QTemporaryDir *_ptr = reinterpret_cast<QTemporaryDir *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTemporaryDir()
void __qt_construct_QTemporaryDir(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTemporaryDir()")
    Q_UNUSED(__java_arguments)
    QTemporaryDir *__qt_this = new(__qtjambi_ptr) QTemporaryDir();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTemporaryDir::QTemporaryDir()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_initialize_1native__Lio_qt_core_QTemporaryDir_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTemporaryDir::QTemporaryDir()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTemporaryDir, sizeof(QTemporaryDir), typeid(QTemporaryDir), false, &deleter_QTemporaryDir, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QTemporaryDir(QString)
void __qt_construct_QTemporaryDir_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTemporaryDir(QString)")
    jstring templateName0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_templateName0 = qtjambi_cast<QString>(__jni_env, templateName0);
    QTemporaryDir *__qt_this = new(__qtjambi_ptr) QTemporaryDir(__qt_templateName0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTemporaryDir::QTemporaryDir(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_initialize_1native__Lio_qt_core_QTemporaryDir_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring templateName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTemporaryDir::QTemporaryDir(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = templateName0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTemporaryDir_cref_QString, sizeof(QTemporaryDir), typeid(QTemporaryDir), false, &deleter_QTemporaryDir, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTemporaryDir
void __qt_destruct_QTemporaryDir(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTemporaryDir")
    reinterpret_cast<QTemporaryDir*>(ptr)->~QTemporaryDir();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTemporaryDir::autoRemove()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_autoRemove_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::autoRemove()const", __qt_this)
        __java_return_value = __qt_this->autoRemove();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::filePath(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_filePath_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::filePath(QString)const", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
        QString __qt_return_value = __qt_this->filePath(__qt_fileName0);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::path()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_path_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::path()const", __qt_this)
        QString __qt_return_value = __qt_this->path();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::remove()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_remove_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::remove()", __qt_this)
        __java_return_value = __qt_this->remove();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::setAutoRemove(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_setAutoRemove_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean b0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::setAutoRemove(bool)", __qt_this)
        __qt_this->setAutoRemove(static_cast<bool>(b0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTemporaryDir(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTemporaryDir>("QTemporaryDir", "io/qt/core/QTemporaryDir");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTemporaryDir, {
        ConstructorInfo(&__qt_construct_QTemporaryDir, nullptr)
       ,ConstructorInfo(&__qt_construct_QTemporaryDir_cref_QString, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTemporaryDir);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QTemporaryDir_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qtemporarydir.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTemporaryDir(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTemporaryDir")
    QTemporaryDir *_ptr = reinterpret_cast<QTemporaryDir *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTemporaryDir()
void __qt_construct_QTemporaryDir(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTemporaryDir()")
    Q_UNUSED(__java_arguments)
    QTemporaryDir *__qt_this = new(__qtjambi_ptr) QTemporaryDir();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QTemporaryDir::QTemporaryDir()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_initialize_1native__Lio_qt_core_QTemporaryDir_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTemporaryDir::QTemporaryDir()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTemporaryDir, sizeof(QTemporaryDir), typeid(QTemporaryDir), 0, false, &deleter_QTemporaryDir, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QTemporaryDir(QString)
void __qt_construct_QTemporaryDir_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTemporaryDir(QString)")
    jstring templateName0 = static_cast<jstring>(__java_arguments[0].l);
    QString __qt_templateName0 = qtjambi_cast<QString>(__jni_env, templateName0);
    QTemporaryDir *__qt_this = new(__qtjambi_ptr) QTemporaryDir(__qt_templateName0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QTemporaryDir::QTemporaryDir(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_initialize_1native__Lio_qt_core_QTemporaryDir_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring templateName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTemporaryDir::QTemporaryDir(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = templateName0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTemporaryDir_cref_QString, sizeof(QTemporaryDir), typeid(QTemporaryDir), 0, false, &deleter_QTemporaryDir, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTemporaryDir
void __qt_destruct_QTemporaryDir(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTemporaryDir")
    reinterpret_cast<QTemporaryDir*>(ptr)->~QTemporaryDir();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTemporaryDir::autoRemove()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_autoRemove_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::autoRemove()const", __this_nativeId)
        __java_return_value = __qt_this->autoRemove();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::errorString()const", __this_nativeId)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::filePath(QString)const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_filePath_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::filePath(QString)const", __this_nativeId)
        QString __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
        QString __qt_return_value = __qt_this->filePath(__qt_fileName0);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::isValid()const", __this_nativeId)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::path()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_path_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::path()const", __this_nativeId)
        QString __qt_return_value = __qt_this->path();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::remove()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_remove_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::remove()", __this_nativeId)
        __java_return_value = __qt_this->remove();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTemporaryDir::setAutoRemove(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_setAutoRemove_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean b0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::setAutoRemove(bool)", __this_nativeId)
        __qt_this->setAutoRemove(static_cast<bool>(b0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTemporaryDir::swap(QTemporaryDir&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTemporaryDir_swap_1native_1ref_1QTemporaryDir__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTemporaryDir *__qt_this = QtJambiAPI::objectFromNativeId<QTemporaryDir>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTemporaryDir::swap(QTemporaryDir&)", __this_nativeId)
        QTemporaryDir& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QTemporaryDir>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTemporaryDir(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTemporaryDir>("QTemporaryDir", "io/qt/core/QTemporaryDir");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QTemporaryDir, {
        ConstructorInfo(&__qt_construct_QTemporaryDir, nullptr)
       ,ConstructorInfo(&__qt_construct_QTemporaryDir_cref_QString, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTemporaryDir);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
